"use client";

import Image from "next/image";

import useEmblaCarousel from "embla-carousel-react";

import BlurFade from "@/components/ui/blur-fade";
import { ImageBaseUrl } from "@/configs/api";
import { Locale } from "@/i18n/routing";

const FeatureCard = ({
	title,
	description,
	path_image,
}: {
	title: string;
	description: string;
	path_image: string;
}) => {
	const image_path = ImageBaseUrl + path_image;
	return (
		<div
			className="rounded-[25px] p-4 md:p-8"
			style={{
				background: "rgba(40, 149, 200, 0.6)",
				border: "2px solid #FFFFFF21",
			}}
		>
			<Image
				src={image_path}
				alt={title}
				width={462}
				height={347}
				style={{
					width: "462px",
					height: "347px",
					objectFit: "cover",
					borderRadius: "15px",
				}}
			/>
			<div className="mt-4">
				<p className="mb-0.5 text-xl font-semibold leading-[60.98px] text-white md:text-[32px] md:font-normal">
					{title}
				</p>
				<p className="text-justify text-sm text-white md:text-base">
					{description}
				</p>
			</div>
		</div>
	);
};

function FeaturesCarousel({ locale, features }: { locale: Locale; features: any }) {
	const [emblaRef] = useEmblaCarousel({
		loop: false,
		align: "start",
		direction: locale === "ar" ? "rtl" : "ltr",
	});

	return (
		<section className="flex flex-col items-center justify-center mt-16 px-3 md:px-12">
			<p className="text-nowrap text-3xl leading-7 text-custom-primary-accent md:text-4xl md:leading-10">
				الميزات
			</p>
			<div className="mt-10 overflow-hidden md:mt-16" ref={emblaRef}>
				<div className="flex justify-center gap-4">
					{features?.map((item: any, index: number) => (
						<BlurFade
							direction="up"
							// delay={index * 0.5}
							duration={0.5}
							inView
							className="flex-[0_0_calc(100%-16px)] p-2 md:flex-[0_0_calc(80%-16px)] lg:flex-[0_0_calc(40%-16px)] 2xl:flex-[0_0_calc(30%-16px)]"
							key={index}
						>
							<FeatureCard
								title={item?.title?.[locale]}
								description={item?.description?.[locale]}
								path_image={item?.thumbnail}
							/>
						</BlurFade>
					))}
				</div>
			</div>
		</section>
	);
}

export default FeaturesCarousel;
